#
# == Class: tsuru::router
#
#  Tsuru router node
#
# === Parameters
#
# [gandalf_host] Gandalf host to
# [gandalf_ipbind_port] Gandalf ip x port to bind
# [gandalf_db_url] Gandalf mongodb url
# [gandalf_db_name] Gandalf mongodb database name
# [gandalf_repositories_path] Git repository root path
# [gandalf_create_repositories] Create repositories base dir
# [gandalf_bare_template_path] Git base template to use
# [gandalf_create_bare_template] Create bare template dir
# [gandalf_user] Gandalf running user
# [gandalf_group] Gandalf running group
# [gandalf_version] Gandalf server package version
# [tsuru_api_host] Tsuru Server API Host
# [tsuru_api_token] Tsuru API Token

class tsuru::router (
  $router_port                       = 80,
  $router_bind                       = '0.0.0.0',
  $router_workers                    = 5,
  $router_max_sockets                = 100,
  $router_dead_backend_ttl           = 30,
  $router_tcp_timeout                = 30,
  $router_http_keep_alive            = true,
  $router_access_log                 = '/var/log/hipache/access_log',
  $router_access_log_mode            = 'file',
  $router_redis_host                 = '127.0.0.1',
  $router_redis_port                 = 6379,
  $router_redis_master_host          = '127.0.0.1',
  $router_redis_master_port          = 6379,
  $router_service_hipache_enable     = true,
  $router_service_hipache_ensure     = 'running',
  $router_service_hchecker_enable    = true,
  $router_service_hchecker_ensure    = 'running',
  $router_hipache_package_version    = latest,
  $router_hchecker_package_version   = latest,
) {

  package { 'node-hipache' :
    ensure  => $hipache_package_version,
    notify  => Service['hipache']
  }

  service { 'hipache':
    ensure     => $service_hipache_ensure,
    enable     => $service_hipache_enable,
    hasrestart => true,
    hasstatus  => true,
    provider   => 'upstart',
    require    => [ Package['node-hipache'], File['/etc/hipache.conf'] ]
  }

  if ($service_hchecker_enable) {

    package { 'hipache-hchecker' :
      ensure  => $hchecker_package_version,
      notify  => Service['hipache-hchecker']
    }

    service { 'hipache-hchecker':
      ensure     => $service_hchecker_ensure,
      enable     => $service_hchecker_enable,
      hasrestart => true,
      hasstatus  => true,
      provider   => 'upstart',
      require    => [ Package['hipache-hchecker'],
                      File['/etc/default/hipache-hchecker'] ]
    }

    file { '/etc/default/hipache-hchecker':
      content => template('hipache/hipache-hchecker.conf.erb'),
      owner   => root,
      group   => root,
      mode    => '0600',
      require => Package['hipache-hchecker'],
      notify  => Service['hipache-hchecker']
    }
  }

  file { '/etc/hipache.conf':
    content => template('hipache/hipache.conf.erb'),
    owner   => root,
    group   => root,
    mode    => '0600',
    require => Package['node-hipache'],
    notify  => Service['hipache']
  }

  file { '/etc/logrotate.d/rsyslog':
    content => template('hipache/logrotate_rsyslog.erb'),
    owner   => root,
    group   => root,
    mode    => '0644',
    require => Package['node-hipache'],
  }

}
